# RPA Web Core

> Core packages for web based [Robot Process Automation](rpa) Tasks

## The problem

Cascading resource import structure for Robot Framework



## Resources

* https://rasjani.github.io/2020/01/05/bundle-resources.html
* https://github.com/rasjani/robotframework-importresource
* https://github.com/rasjani/robotframework-importresource-testdata




#### Get in touch with me

> I am always looking for Jobs ... :sunglasses:

* [Github](https://github.com/avimehenwal/)
* [My Website](https://avimehenwal.in)
* [Twitter Handle](https://twitter.com/avimehenwal)
* [LinkedIn](https://in.linkedin.com/in/avimehenwal)
* [Stackoverflow](https://stackoverflow.com/users/1915935/avi-mehenwal)

<a href="https://www.buymeacoffee.com/F1j07cV" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" style="height: 51px !important;width: 217px !important;" ></a>

 Spread Love :hearts: and not :no_entry_sign: hatred   [![Twitter Follow](https://img.shields.io/twitter/follow/avimehenwal.svg?style=social)](https://twitter.com/avimehenwal)


[rpa]: https://en.wikipedia.org/wiki/Robotic_process_automation
